Fairness loss methods
=============================

Base loss method definition
-----------------------------
.. automodule:: fairret.loss.base
    :members:
    :show-inheritance:

Violation loss methods 
-----------------------------
.. automodule:: fairret.loss.violation
    :members:
    :show-inheritance:


Projection loss methods
-----------------------------
   
.. automodule:: fairret.loss.projection
    :members:
    :show-inheritance:


